This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[Ada] Fix various typos


Tested on i586-suse-linux, applied on the mainline.


2008-04-08  Eric Botcazou  <ebotcazou@adacore.com>

	* decl.c (prepend_attributes): Fix typo.
	* trans.c (Pragma_to_gnu): Likewise.
	* utils.c (gnat_genericize): Likewise.


-- 
Eric Botcazou
Index: decl.c
===================================================================
--- decl.c	(revision 134093)
+++ decl.c	(working copy)
@@ -2183,7 +2183,7 @@ gnat_to_gnu_entity (Entity_Id gnat_entit
 	      gnu_type = gnat_to_gnu_type (Original_Array_Type (gnat_entity));
 	      for (index = array_dim - 1; index >= 0; index--)
 		gnu_type = TREE_TYPE (gnu_type);
-	
+
 	      /* One of the above calls might have caused us to be elaborated,
 		 so don't blow up if so.  */
 	      if (present_gnu_tree (gnat_entity))
@@ -5107,7 +5107,7 @@ prepend_attributes (Entity_Id gnat_entit
 						  (First (gnat_assoc)))))));
 	  }
 
-	switch (Get_Pragma_Id (Pragma_Identifier (Chars (gnat_temp))))
+	switch (Get_Pragma_Id (Chars (Pragma_Identifier (gnat_temp))))
 	  {
 	  case Pragma_Machine_Attribute:
 	    etype = ATTR_MACHINE_ATTRIBUTE;
Index: trans.c
===================================================================
--- trans.c	(revision 134093)
+++ trans.c	(working copy)
@@ -691,7 +691,7 @@ Pragma_to_gnu (Node_Id gnat_node)
       || !Is_Pragma_Name (Chars (Pragma_Identifier (gnat_node))))
     return gnu_result;
 
-  switch (Get_Pragma_Id (Pragma_Identifier (Chars (gnat_node))))
+  switch (Get_Pragma_Id (Chars (Pragma_Identifier (gnat_node))))
     {
     case Pragma_Inspection_Point:
       /* Do nothing at top level: all such variables are already viewable.  */
@@ -3673,7 +3673,6 @@ gnat_to_gnu (Node_Id gnat_node)
 
       /* If the result is a pointer type, see if we are improperly
 	 converting to a stricter alignment.  */
-
       if (STRICT_ALIGNMENT && POINTER_TYPE_P (gnu_result_type)
 	  && IN (Ekind (Etype (gnat_node)), Access_Kind))
 	{
Index: utils.c
===================================================================
--- utils.c	(revision 134092)
+++ utils.c	(working copy)
@@ -2098,7 +2098,7 @@ gnat_genericize (tree fndecl)
      type, and the gimplifier ICEs on such attempts.  Second, the middle-end
      now relies on a different attribute for such cases (DECL_BY_REFERENCE on
      RESULT/PARM_DECLs), and expects the user invisible by-reference-ness to
-     be explicitely accounted for by the front-end in the function body.
+     be explicitly accounted for by the front-end in the function body.
 
      We achieve the complete transformation in two steps:
 
@@ -2116,7 +2116,7 @@ gnat_genericize (tree fndecl)
      strategy, which escapes the gimplifier temporary creation issues by
      creating it's own temporaries using TARGET_EXPR nodes.  Our way relies
      on simple specific support code in aggregate_value_p to look at the
-     target function result decl explicitely.  */
+     target function result decl explicitly.  */
 
   struct pointer_set_t *p_set;
   tree decl_result = DECL_RESULT (fndecl);
@@ -2124,7 +2124,7 @@ gnat_genericize (tree fndecl)
   if (!DECL_BY_REFERENCE (decl_result))
     return;
 
   /* Make the DECL_RESULT explicitely by-reference and adjust all the
      occurrences in the function body using the common tree-walking facility.
      We want to see every occurrence of the result decl to adjust the
      referencing tree, so need to use our own pointer set to control which
@@ -2124,7 +2124,7 @@ gnat_genericize (tree fndecl)
     return;
 
-  /* Make the DECL_RESULT explicitely by-reference and adjust all the
+  /* Make the DECL_RESULT explicitly by-reference and adjust all the
      occurrences in the function body using the common tree-walking facility.
      We want to see every occurrence of the result decl to adjust the

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]